tidy.boottest: S3 method to summarize objects of class boottest into tidy...

View source: R/tidy_boottest.R

tidy.boottestR Documentation

S3 method to summarize objects of class boottest into tidy data.frame

Description

S3 method to summarize objects of class boottest into tidy data.frame

Usage

## S3 method for class 'boottest'
tidy(object, ...)

Arguments

object

object of type boottest

...

Further arguments passed to or from other methods.

Value

A tidy data.frame with estimation results for objects of type boottest


s3alfisc/wildboottestjlr documentation built on June 16, 2022, 7:40 a.m.