View source: R/tidy_boottest.R
| tidy.boottest | R Documentation |
S3 method to summarize objects of class boottest into tidy data.frame
## S3 method for class 'boottest' tidy(object, ...)
object |
object of type boottest |
... |
Further arguments passed to or from other methods. |
A tidy data.frame with estimation results for objects of type boottest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.